CedarBackup3.actions.constants — cedar-backup3 3.10.0 documentation

# CedarBackup3.actions.constants

Provides common constants used by standard actions. :author: Kenneth J. Pronovici <pronovic@ieee.org>

## Module Contents

CedarBackup3.actions.constants.DIR_TIME_FORMAT = '%Y/%m/%d'

CedarBackup3.actions.constants.DIGEST_EXTENSION = 'sha'

CedarBackup3.actions.constants.INDICATOR_PATTERN = ['cback\\..*']

CedarBackup3.actions.constants.COLLECT_INDICATOR = 'cback.collect'

CedarBackup3.actions.constants.STAGE_INDICATOR = 'cback.stage'

CedarBackup3.actions.constants.STORE_INDICATOR = 'cback.store'